@@ -93,7 +93,9 @@ class powerswitch:
         """ Verify we can reach the switch, returns true if ok """
         return self.geturl()
     def geturl(self,url='index.htm') :
-        """ Get a URL from the userid/password protected powerswitch page """
+        """ Get a URL from the userid/password protected powerswitch page 
+            Return None on failure
+        """
         request = urllib2.Request("http://%s/%s" % (self.hostname,url))
         base64string = base64.encodestring('%s:%s' % (self.userid, self.password)).replace('\n', '')
         request.add_header("Authorization", "Basic %s" % base64string)   
@@ -105,21 +107,32 @@ class powerswitch:
             return None
         return result
     def off(self,outlet=0):
-        """ Turn off a power to an outlet """
+        """ Turn off a power to an outlet 
+            False = Success
+            True = Fail
+        """
         self.geturl(url= 'outlet?%d=OFF' % outlet)
         return self.status(outlet) != 'OFF'
     def on(self,outlet=0):
-        """ Turn on power to an outlet """
+        """ Turn on power to an outlet 
+            False = Success
+            True = Fail
+        """
         self.geturl(url= 'outlet?%d=ON' % outlet)
         return self.status(outlet) != 'ON'
     def cycle(self,outlet=0):
-        """ Cycle power to an outlet """
+        """ Cycle power to an outlet 
+            False = Success
+            True = Fail
+        """
+        
         start_status=self.status(outlet)
-        if start_status:
+        if start_status != 'Unknown':
           self.off(outlet)
           time.sleep(CYCLETIME)
           self.on(outlet)
-          return None
+        else:
+          return True
         return self.status(outlet) != start_status
     def statuslist(self):
         """ Return the status of all outlets in a list, 
@@ -136,7 +149,6 @@ class powerswitch:
             return None
         for temp in root.findAll('tr'):
             columns=temp.findAll('td')
-            #print len(columns)
             if len(columns) == 5:
                 plugnumber=columns[0].string
                 hostname=columns[1].string
